@@ -108,13 +108,15 @@ my $RunCmd = sub($$)
              $Ifconfig{$CName}{$^O}{$OsName}{$OsVers}{'ifconfig'}          :
              $Ifconfig{$CName}{$^O}{'ifconfig'}).' 2>&1';
   
-  #print "\n=== RunCmd ===\n\$CName: $CName, \$Iface: $Iface, \$Logic: $Logic, \$Addr: $Addr, \$Mask: $Mask\n";
+  $DEBUG && print STDERR "\n=== RunCmd ===\n\$CName: $CName, \$Iface: $Iface, \$Logic: $Logic, \$Addr: $Addr, \$Mask: $Mask\n";
   
   $Cmd =~ s{%Iface%}{$Iface}gsex;
   $Cmd =~ s{%Logic%}{$Logic}gsex;
   $Cmd =~ s{%Addr%}{$Addr}gsex;
   $Cmd =~ s{%Mask%}{$Mask}gsex;
   
+  $DEBUG && print STDERR "Cmd is ==$Cmd==\n";
+
   my $saveLang = $ENV{'LANG'} || '';
   $ENV{'LANG'} = 'C';
   my @Output   = `$Cmd`;
